@@ -10,21 +10,20 @@
 class OSD *osd;
 
 OSD::OSD() {
-	this->time = 0;
+	this->time  = 0;
 	this->lines = 0;
-	this->text = "";
+	this->text  = "";
 }
 
 void OSD::set_message(string text, uint32_t ms) {
-
-	this->text = text;
+	this->text  = text;
 	this->lines = 1;
-	for(int loop=0;loop< text.length(); loop++) {
+	for (unsigned int loop = 0; loop < text.length(); loop++) {
 		if (text[loop] == '\n') {
 			this->lines++;
 		}
 	}
-	this->time = ms/20; // set it to number of frames
+	this->time = ms / 20; // set it to number of frames
 }
 
 uint32_t OSD::get_time() {
@@ -34,8 +33,7 @@ uint32_t OSD::get_time() {
 	return (this->time);
 }
 
-string OSD::get_text(uint8_t &lines) {
-
+string OSD::get_text(uint8_t&lines) {
 	lines = this->lines;
 	return this->text;
 }
